#!/bin/sh

#### WARNING  WARNING  WARNING  WARNING  WARNING  WARNING ####
# Replacing CONFIG_* variables with hard coded values will most likely cause
# problems in phStbKBufMgr, since the phStbKBufMgr kernel module uses generated
# C code based on values in $BUILDROOT/prjconfig.h .
# THUS... use prjconfig and "prjmake all" to ensure that this file
# in $ROOTFS and the phStbKBufMgr kernel module are consistent.
#### WARNING  WARNING  WARNING  WARNING  WARNING  WARNING ####

# 'resolution' can be set to one of:
#
# 1280x720x50p 1280x720x60p 1280x720x59.94p
# 1920x1080x50i 1920x1080x60i 1920x1080x59.94i
# 1920x1080x29.97p
#
# 640x480x60p 800x600x75p 1024x768x75p 1360x768x60p
#
# 720x480x60p 720x480x59.94p 720x576x50p
#
# PAL-BG PAL-I PAL-M PAL-N PAL-NC SECAM NTSC-M NTSC-M-JPN

resolution=1920x1080x50i

# 'graphics_mode' can be set to one of:
#
# ARGB     - 32 bit ARGB
# ARGB1555 - 16 bit ARGB [1 Bit Alpha]
# ARGB4444 - 16 bit ARGB [4 Bit Alpha]
# RGB16    - 16 bit  RGB [No alpha]
# LUT8     -  8 bit CLUT

graphics_mode=ARGB

rc_protocol=NEC

# The size (in KiB) of the buffer space used by alternate directFB allocation pool
alt_directfb_bufsize=0

# Enable simultaneous HD and SD outputs
hdsd_enable=1


avga_enable=0

# Set width and height to zero (0) to use standard framebuffer resolutions
fb_width=0
fb_height=0

# Set the number of frame buffers to be created
num_fb=1


double_buffered=0

kernelRelease=$(uname -r)
c=/lib/modules/$kernelRelease/kernel/drivers/char/hw_random
i=/lib/modules/$kernelRelease/kernel/drivers/input
w=/lib/modules/$kernelRelease/kernel/drivers/watchdog
x=/lib/modules/$kernelRelease/extra


if [ -f $i/evdev.ko ]; then
   insmod $i/evdev.ko
fi

if [ -f $c/pnx833x-rng.ko ]; then
   insmod $c/pnx833x-rng.ko
fi

# Set up any necessary module parameters
# Set up the DirectFB display variables depending on the initial mode
case ${resolution} in
"1280x720x60p" | "1280x720x59.94p" | "1280x720x50p")
   if [ "${num_fb}" == 1 ]; then
         display_width=1280
      display_height=720
         fb_width=${display_width}
      fb_height=${display_height}
   else
      display_width=720
      display_height=720
   fi
   ;;
"1920x1080x60i" | "1920x1080x59.94i" | "1920x1080x50i" | "1920x1080x29.97p")
   if [ "${num_fb}" == 1 ]; then
         display_width=1920
      display_height=1080
         fb_width=${display_width}
      fb_height=${display_height}
   else
      display_width=960
      display_height=540
   fi
   ;;
"720x576x50p" | "PAL-BG" | "PAL-I" | "PAL-N" | "PAL-NC" | "SECAM")
   display_width=720
   display_height=576
   ;;
"720x480x60p" | "720x480x59.94p" | "PAL-M" | "NTSC-M" | "NTSC-M-JPN")
   display_width=720
   display_height=480
   ;;
"640x480x60p")
   display_width=640
   display_height=480
   ;;
"800x600x75p")
   num_fb=1
   display_width=800
   display_height=600
   fb_width=${display_width}
   fb_height=${display_height}
   ;;
"1024x768x75p")
   num_fb=1
   display_width=1024
   display_height=768
   fb_width=${display_width}
   fb_height=${display_height}
   ;;
"1360x768x60p")
   num_fb=1
   display_width=1360
   display_height=768
   fb_width=${display_width}
   fb_height=${display_height}
   ;;
*)
   echo "Invalid Display Mode found"
   exit 1
   ;;
esac

opts_phStbDraw=scratch_memory_size=524288

opts_phStbHdmi=mode_option=${resolution}
opts_phStbCore=hdmi=1
opts_tda998x="gpio_int_pin=10"
tda998x_module=$(exStbDetectHDMI)
[ -z "$tda998x_module" ] && tda998x_module=tda9983

opts_phStbVo="mode_option=${resolution} hdsd_enable=$hdsd_enable"
opts_phStbVideoRenderer="video_mode=${resolution} hdsd_enable=$hdsd_enable background=0x000000 avga_enable=$avga_enable"
opts_phStbVideoRenderer="$opts_phStbVideoRenderer hdsd_flicker_filter_enable=1"
opts_phStbRCProtocol=rc_protocol=${rc_protocol}
opts_phStbRCProtocol="$opts_phStbRCProtocol input=1"
opts_phStbFB="width=${fb_width} height=${fb_height} num_fb=${num_fb} double_buffered=${double_buffered} background=0x00000000"

opts_phStbFB="$opts_phStbFB extended_fb_mem=0"
opts_phStbFB="$opts_phStbFB cached_memory=0"
opts_phStbFB="$opts_phStbFB gfx_memory_size=12441600"
opts_phStbFB="$opts_phStbFB gfx_display_mode=${graphics_mode}"

opts_phStbCore="$opts_phStbCore Core_sharedMemory=1"

insmod $x/phStbDbg.ko
#### THIS IS THE PLACE TO ADD tmdbg statements like:
#### tmdbg dbg enable phStbKBufMgr

for m in phKernelIfce phStbOsal phStbKBufMgr; do
    eval insmod $x/$m.ko \$opts_$m
done

# phStbNetDev depends on phStbKBufMgr
# phStbBootDsp depends on phStbNetDev
insmod $x/phStbNetDev.ko mtu=500 subnet=192.168.251
hostip=192.168.251.1
ifconfig ipc0 $hostip

opts_phStbBootDsp=cmdline="\"phStbNetDev.subnet=192.168.251 console=ttyS1,115200\""

# Enable telnet from external network to MIPS2 (should be disabled before production...)
echo 1 >/proc/sys/net/ipv4/ip_forward

opts_phStbRSServer=multi

# Any HDMI driver must be loaded after phStbHdmi
insmod $x/phStbHdmi.ko $opts_phStbHdmi
insmod $x/${tda998x_module}.ko $opts_tda998x

for m in \
	phStbIpc \
	phStbCore \
	phStbRSServer \
	 phStbMmio  \
	 phStbDraw  \
	phStbVideoRenderer \
	phStbVo \
	 phStbFB \
	phStbBootDsp \
	 at24c64  \
	 ak470x  \
	 \
	phStbGpio \
	 \
	 phStbRCProtocol  \
	 phStbIR  \
	 \
	 \
	 \
	 \
; do
    eval insmod $x/$m.ko \$opts_$m
done
rmmod phStbBootDsp

if [  "${fb_width}" != 0 ]; then
   if [  "${fb_width}" != ${display_width} ]; then
       display_width=${fb_width}
       echo "Non-standard Framebuffer display width - update /etc/fb.modes"
   fi
fi

if [  "${fb_height}" != 0 ]; then
   if [  "${fb_height}" != ${display_height} ]; then
       display_height=${fb_height}
       echo "Non-standard Framebuffer display height - update /etc/fb.modes"
   fi
fi

if [ -f $w/pnx833x_wdt.ko ]; then
    insmod $w/pnx833x_wdt.ko pnx833x_wdt_timeout_seconds=30
fi

# Set up the DirectFB init file
echo "mode="${display_width}"x"${display_height} > /etc/directfbrc
echo "pixelformat=${graphics_mode}" >> /etc/directfbrc
echo "no-vt-switch" >> /etc/directfbrc
echo "no-cursor" >> /etc/directfbrc
echo "system=devmem" >> /etc/directfbrc
echo "video-phys="$(cat /sys/module/phStbFB/parameters/gfx_memory_start) >> /etc/directfbrc
echo "video-length="$(cat /sys/module/phStbFB/parameters/gfx_memory_available) >> /etc/directfbrc
# The lines below stop the layer flipping at startup.
echo "init-layer=0" >> /etc/directfbrc
echo "layer-bg-none" >> /etc/directfbrc
if [ "${num_fb}" == 2 ]; then
echo "init-layer=1" >> /etc/directfbrc
echo "layer-bg-none" >> /etc/directfbrc
fi
# Uncomment the lines below to help with debugging DirectFB issues.
#echo "debug = NXP/STB22x/2D" >> /etc/directfbrc
#echo "debug = NXP/STB22x/Encoder" >> /etc/directfbrc
#echo "debug = NXP/STB22X/Gfx" >> /etc/directfbrc
#echo "debug = NXP/STB22X/GSurf" >> /etc/directfbrc
#echo "debug = NXP/STB22X/GLock" >> /etc/directfbrc
#echo "debug = NXP/STB22x/Mixer" >> /etc/directfbrc
#echo "debug = NXP/STB22x/Output" >> /etc/directfbrc
#echo "debug = NXP/STB22X/Screen" >> /etc/directfbrc
#echo "debug = NXP/STB22X/Utils" >> /etc/directfbrc
#echo "debug = NXP/STB22X/Video" >> /etc/directfbrc
#echo "debug = NXP/STB22X/VSurf" >> /etc/directfbrc
#echo "debug = NXP/STB22X/VLock" >> /etc/directfbrc
# Uncomment the lines below to help debug VideoProvider issues.
#echo "debug = NXP/STB22x/VideoProviderASF" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderCommon" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderES" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderTS" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderV4L" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderGst" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderGstPlatform" >> /etc/directfbrc
#echo "debug = NXP/STB22x/VideoProviderGstEvents" >> /etc/directfbrc
# Uncomment the lines below to help debug ImageProvider issues.
#echo "debug = NXP/STB22x/ImageProvider" >> /etc/directfbrc
# The sections below help debug DirectFB.
#echo "debug = Core/Font" >> /etc/directfbrc
#echo "debug = Core/Font/Surf" >> /etc/directfbrc
#echo "debug = Core/Graphics" >> /etc/directfbrc
#echo "debug = Core/GraphicsOps" >> /etc/directfbrc
#echo "debug = Core/GfxState" >> /etc/directfbrc
#echo "debug = Core/Input" >> /etc/directfbrc
#echo "debug = Core/Input/Evt" >> /etc/directfbrc
#echo "debug = Core/Layers" >> /etc/directfbrc
#echo "debug = Core/Surface" >> /etc/directfbrc
#echo "debug = Core/SurfBuffer" >> /etc/directfbrc
#echo "debug = Core/SurfaceCore" >> /etc/directfbrc
#echo "debug = Core/System" >> /etc/directfbrc
#echo "debug = Core/Windows" >> /etc/directfbrc
#echo "debug = Core/WindowStack" >> /etc/directfbrc
#echo "debug = Core/WM" >> /etc/directfbrc
#echo "debug = DevMem/Surfaces" >> /etc/directfbrc
#echo "debug = DevMem/SurfLock" >> /etc/directfbrc
#echo "debug = Direct/Interface" >> /etc/directfbrc
#echo "debug = Direct/Clock" >> /etc/directfbrc
#echo "debug = Direct/Main" >> /etc/directfbrc
#echo "debug = Direct/Mem" >> /etc/directfbrc
#echo "debug = Direct/Modules" >> /etc/directfbrc
#echo "debug = Direct/Signals" >> /etc/directfbrc
#echo "debug = Direct/Thread" >> /etc/directfbrc
#echo "debug = Direct/Thread/Init" >> /etc/directfbrc
#echo "debug = DirectFB/Core" >> /etc/directfbrc
#echo "debug = IDFBEventBuffer" >> /etc/directfbrc
#echo "debug = IDirectFB" >> /etc/directfbrc
#echo "debug = IDirectFBDisplayLayer" >> /etc/directfbrc
#echo "debug = IDirectFBSurface" >> /etc/directfbrc
#echo "debug = IDirectFBSurfaceL" >> /etc/directfbrc
#echo "debug = IDirectFBSurfaceW" >> /etc/directfbrc
#echo "debug = SurfaceManager" >> /etc/directfbrc
#echo "debug = WM/Default" >> /etc/directfbrc
# The following help to debug any GTK issues that might arise.
#echo "debug = GDKDFB/Crossing" >> /etc/directfbrc
#echo "debug = GDKDFB/CrossX" >> /etc/directfbrc
#echo "debug = GDKDFB/Drawable" >> /etc/directfbrc
#echo "debug = GDKDFB/DrawClip" >> /etc/directfbrc
#echo "debug = GDKDFB/Events" >> /etc/directfbrc
#echo "debug = GDKDFB/EventCheck" >> /etc/directfbrc
#echo "debug = GDKDFB/EventTrans" >> /etc/directfbrc
#echo "debug = GDKDFB/Grab/Kbd" >> /etc/directfbrc
#echo "debug = GDKDFB/Grab/Ptr" >> /etc/directfbrc
#echo "debug = GDKDFB/Scroll" >> /etc/directfbrc
#echo "debug = GDKDFB/Visual" >> /etc/directfbrc
#echo "debug = GDKDFB/WinIDTable" >> /etc/directfbrc
#echo "debug = GDKDFB/WinIDLookup" >> /etc/directfbrc

# Ensure that Multicast streams can be accessed through either Ethernet connection
/sbin/route add -net 224.0.0.0 netmask 240.0.0.0 dev eth0 >/dev/null 2>&1
/sbin/route add -net 224.0.0.0 netmask 240.0.0.0 dev eth1 >/dev/null 2>&1

